@@ -30,12 +30,15 @@
 extern crate amplify;
 #[macro_use]
 extern crate strict_encoding;
+#[cfg(feature = "miniscript")]
+extern crate miniscript_crate as miniscript;
 
 mod descriptor;
 mod input;
 pub mod locks;
 #[cfg(feature = "miniscript")]
 mod templates;
+mod tweaks;
 
 pub use descriptor::{
     BareDescriptor, CompositeDescrType, DescrVariants, Error, InnerDescrType, OuterDescrType,
@@ -44,3 +47,6 @@ pub use descriptor::{
 pub use input::InputDescriptor;
 #[cfg(feature = "miniscript")]
 pub use templates::ScriptTemplate;
+#[cfg(feature = "miniscript")]
+pub use tweaks::Tret;
+pub use tweaks::{OutputTweak, PubkeyTweak, ScriptTweak, TapretTweak};
